#[repr(u8)]pub enum StickerType {
Standard = 1,
Guild = 2,
}Expand description
Variants
Standard = 1
an official sticker in a pack, part of Nitro or in a removed purchasable pack
Guild = 2
a sticker uploaded to a guild for the guild’s members