Member

Struct Member 

pub struct Member {
    pub user: User,
    pub nick: Option<String>,
    pub avatar: Option<String>,
    pub roles: Vec<Snowflake>,
    pub joined_at: String,
    pub premium_since: Option<String>,
    pub deaf: bool,
    pub mute: bool,
    pub flags: u64,
    pub pending: Option<bool>,
    pub permissions: Option<Permissions>,
    pub communication_disabled_until: Option<String>,
}
Fields

user: User

User this member represents

nick: Option<String>

Guild nickname

avatar: Option<String>

Guild member’s guild avatar hash

roles: Vec<Snowflake>

Array of role snowflakes

joined_at: String

When the user joined the guild formatted as ISO timestamp

premium_since: Option<String>

When the user started boosting the guild

deaf: bool

Whether the user is deafened in voice channels

mute: bool

Whether the user is muted in voice channels

flags: u64pending: Option<bool>

Whether the user has not yet passed the guild’s Membership Screening requirements

permissions: Option<Permissions>

total permissions of the member in the channel, including overwrites, returned when in the interaction object

communication_disabled_until: Option<String>

when the user’s timeout will expire and the user will be able to communicate in the guild again, null or a time in the past if the user is not timed out