ChannelSelect

Type Alias ChannelSelect 

pub type ChannelSelect = SelectMenu<8>;
Select menu for picking from channels

Aliased Type

pub struct ChannelSelect {
    pub t: TypeField<8>,
    pub custom_id: String,
    pub options: Option<Vec<SelectOption>>,
    pub channel_types: Option<Vec<ChannelType>>,
    pub placeholder: Option<String>,
    pub min_values: Option<i32>,
    pub max_values: Option<i32>,
    pub disabled: Option<bool>,
}

Fields

t: TypeField<8>

Type of select menu component (text: 3, user: 5, role: 6, mentionable: 7, channels: 8)

custom_id: String

ID for the select menu; max 100 characters

options: Option<Vec<SelectOption>>

Specified choices in a select menu (only required and available for string selects (type 3); max 25

channel_types: Option<Vec<ChannelType>>

List of channel types to include in the channel select component (type 8)

placeholder: Option<String>

Placeholder text if nothing is selected; max 150 characters

min_values: Option<i32>

Minimum number of items that must be chosen (defaults to 1); min 0, max 25

max_values: Option<i32>

Maximum number of items that can be chosen (defaults to 1); max 25

disabled: Option<bool>

Whether select menu is disabled (defaults to false)